@@ -13,6 +13,8 @@ module GirFFI
   # repository.
   module Builder
     module Type
+      CACHE = {}
+
       TYPE_MAP = {
         :callback => Callback,
         :constant => Constant,
@@ -27,6 +29,11 @@ module GirFFI
       def self.build info
         TYPE_MAP[info.info_type].new(info).build_class
       end
+
+      # TODO: Pull up to include :function and :module
+      def self.builder_for info
+        TYPE_MAP[info.info_type].new(info)
+      end
     end
   end
 end
